@@ -1,12 +1,9 @@
 import time
 import inspect
-try: 
-    from cStringIO import StringIO
-except ImportError: 
-    import StringIO
+
 from django.core import cache
 from django.core.cache.backends.base import BaseCache
-from django.template.loader import render_to_string
+from django.utils.translation import ugettext_lazy as _
 from debug_toolbar.panels import DebugPanel
 
 class CacheStatTracker(BaseCache):
@@ -14,7 +11,7 @@ class CacheStatTracker(BaseCache):
     def __init__(self, cache):
         self.cache = cache
         self.reset()
-
+    
     def reset(self):
         self.calls = []
         self.hits = 0
@@ -24,11 +21,11 @@ class CacheStatTracker(BaseCache):
         self.get_many = 0
         self.deletes = 0
         self.total_time = 0
-
+    
     def _get_func_info(self):
         stack = inspect.stack()[2]
         return (stack[1], stack[2], stack[3], stack[4])
-
+    
     def get(self, key, default=None):
         t = time.time()
         value = self.cache.get(key, default)
@@ -41,7 +38,7 @@ class CacheStatTracker(BaseCache):
         self.gets += 1
         self.calls.append((this_time, 'get', (key,), self._get_func_info()))
         return value
-
+    
     def set(self, key, value, timeout=None):
         t = time.time()
         self.cache.set(key, value, timeout)
@@ -49,15 +46,15 @@ class CacheStatTracker(BaseCache):
         self.total_time += this_time * 1000
         self.sets += 1
         self.calls.append((this_time, 'set', (key, value, timeout), self._get_func_info()))
-
+    
     def delete(self, key):
         t = time.time()
-        self.instance.delete(key, value)
+        self.cache.delete(key)
         this_time = time.time() - t
         self.total_time += this_time * 1000
         self.deletes += 1
         self.calls.append((this_time, 'delete', (key,), self._get_func_info()))
-
+    
     def get_many(self, keys):
         t = time.time()
         results = self.cache.get_many(keys)
@@ -76,9 +73,11 @@ class CacheDebugPanel(DebugPanel):
     Panel that displays the cache statistics.
     """
     name = 'Cache'
+    template = 'debug_toolbar/panels/cache.html'
     has_content = True
-
-    def __init__(self):
+    
+    def __init__(self, *args, **kwargs):
+        super(CacheDebugPanel, self).__init__(*args, **kwargs)
         # This is hackish but to prevent threading issues is somewhat needed
         if isinstance(cache.cache, CacheStatTracker):
             cache.cache.reset()
@@ -86,20 +85,19 @@ class CacheDebugPanel(DebugPanel):
         else:
             self.cache = CacheStatTracker(cache.cache)
             cache.cache = self.cache
-
+    
     def nav_title(self):
-        return 'Cache: %.2fms' % self.cache.total_time
-
+        return _('Cache: %.2fms') % self.cache.total_time
+    
     def title(self):
-        return 'Cache Usage'
-
+        return _('Cache Usage')
+    
     def url(self):
         return ''
-
-    def content(self):
-        context = dict(
-            cache_calls = len(self.cache.calls),
-            cache_time = self.cache.total_time,
-            cache = self.cache,
-        )
-        return render_to_string('debug_toolbar/panels/cache.html', context)
\ No newline at end of file
+    
+    def process_response(self, request, response):
+        self.record_stats({
+            'cache_calls': len(self.cache.calls),
+            'cache_time': self.cache.total_time,
+            'cache': self.cache,
+        })
